#!/usr/bin/env python
# encoding: utf-8
"""
Collection.py

Created by Dave Evans on 2010-03-11.
Copyright (c) 2010 Fermilab. All rights reserved.
"""

from WMCore.DataStructs.WMObject import WMObject
import WMCore.ACDC.CollectionTypes as CollectionTypes


class Collection(dict, WMObject):
    def __init__(self, **options):
        dict.__init__(self)
        WMObject.__init__(self)
        self.setdefault("name", None)
        self.setdefault("type", CollectionTypes.GenericCollection)
        self.setdefault("filesets", [])
        self.update(options)

    def create(self, unique=False):
        """
        _create_

        Create this Collection in the back end

        """
        pass

    def populate(self):
        """
        _populate_

        Pull in all filesets & file entries

        """
        pass

    def drop(self):
        """
        _drop_

        Remove this collection.
        """
        pass

    def addFileset(self, fileset):
        """
        _addFiles_

        Add a fileset to the collection.
        """
        fileset.setCollection(self)
        self["filesets"].append(fileset)
        return



"""
_ResultSet_

A class to read in a SQLAlchemy result proxy and hold the data, such that the
SQLAlchemy result sets (aka cursors) can be closed. Make this class look as much
like the SQLAlchemy class to minimise the impact of adding this class.
"""

from builtins import object
import threading


class ResultSet(object):
    def __init__(self):
        self.data = []
        self.keys = []

    def close(self):
        return

    def fetchone(self):
        if len(self.data) > 0:
            return self.data[0]
        else:
            return []

    def fetchall(self):
        return self.data

    def add(self, resultproxy):

        myThread = threading.currentThread()

        if resultproxy.closed:
            return
        elif resultproxy.returns_rows:
            for r in resultproxy:
                if len(self.keys) == 0:
                    # do not modernize next line. 
                    # r is a `sqlalchemy.engine.result.RowProxy`, not a `dict`
                    self.keys.extend(r.keys()) 
                self.data.append(r)

        return
